%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Ce document est sous licence Creative Commons                                              %
% Paternit - Pas d'Utilisation Commerciale - Partage des Conditions Initiales  l'Identique %
% 3.0 France                                                                                 %
% http://creativecommons.org/licenses/by-nc-sa/3.0/deed.fr                                   %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\NeedsTeXFormat{LaTeX2e}[1995/12/01]
\ProvidesClass{ecn}[2008/08/08 v1.0 libreslivres]

\DeclareOption*{\PassOptionsToClass{\CurrentOption}{book}}
\ProcessOptions

\LoadClass{book}
\RequirePackage[T1]{fontenc}
\RequirePackage[latin1]{inputenc}
\RequirePackage[dvips]{graphicx}
\RequirePackage[dvips]{color}
\RequirePackage{fancyhdr}
\RequirePackage{fancybox}
\RequirePackage{pstricks,pst-text,pst-plot,pst-all}
\RequirePackage[small,hang]{caption2}
\RequirePackage{amsmath}
\RequirePackage{amssymb}
\RequirePackage{amsfonts}
\RequirePackage{subfigure}
\RequirePackage{psfrag}
\RequirePackage{array}
\RequirePackage{eso-pic}
\RequirePackage[backref,colorlinks=true,dvips,urlcolor=gray,bookmarks=true,pagebackref]{hyperref}
\RequirePackage{upgreek}
\RequirePackage{lmodern}

%paisseur des lignes:
\newlength{\epaisseur}
\setlength{\epaisseur}{.3mm}

% dfinition du d romain de drivation
\newcommand{\ud}{\mathrm{d}}

% dfinition des captions des objets flottants
\renewcommand{\captionfont}{\normalfont\it\selectfont}
\newcommand{\subcaptionfont}{\normalfont\selectfont}
\renewcommand{\captionlabelfont}{\bf \sffamily}
\renewcommand{\captionlabeldelim}{ -}
\newcommand{\chapternumfont}{\normalfont\fontsize{50}{30}\bfseries\selectfont}
\newcommand{\annexnumfont}{\normalfont\fontsize{50}{15}\bfseries\selectfont}

% environnement de liste
\newenvironment{maliste}%
{ \begin{list}%
    {$-$}%
    {\setlength{\labelwidth}{30pt}%
     \setlength{\leftmargin}{30pt}%
     \setlength{\itemsep}{2pt}}}%
{ \end{list} }

% environnement de sous-liste
\newenvironment{maliste2}%
{ \begin{list}%
    {$-$}%
    {\setlength{\labelwidth}{20pt}%
     \setlength{\leftmargin}{20pt}%
     \setlength{\itemsep}{1pt}}}%
{ \end{list}} 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\newdimen\betweenumberspace          % dimension for space between
\betweenumberspace=5\p@               % number and text of titles

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% dfinition des parties
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\def\@part[#1]#2#3{\refstepcounter{part}
    \addcontentsline{toc}{part}{\hfill\large\thepart\hskip\betweenumberspace-\hskip\betweenumberspace #1\hfill}
    \addtocontents{toc}{\vspace{-3mm}\protect\mbox{}\protect\hrulefill\par}
    {\centering \normalfont\sffamily\bfseries\Huge\partname\ \thepart\par
            \vskip 30pt 
    \psframebox[linearc=0.2,cornersize=absolute,framesep=10pt]{\begin{minipage}[t]{0.9\textwidth}\centering \normalfont\sffamily\bfseries\huge
            \textcolor{bleu}{#2}\end{minipage}}
    
    \par\vskip 30pt 
    \centering \normalfont\sffamily\bfseries \large #3\par\vskip 50pt }
    %\@endpart
    }

\def\@endpart{\vfil\newpage
    \if@twoside
       \hbox{}
       \thispagestyle{empty}
       \newpage
    \fi
    \if@tempswa
       \twocolumn
    \fi}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% dfinition des parties non numrotes
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\newcommand\starpart[1]{%
  \if@openright
    \cleardoublepage
  \else
    \clearpage
  \fi
  \thispagestyle{plain}%
  \if@twocolumn
    \onecolumn
    \@tempswatrue
  \else
    \@tempswafalse
  \fi
  \null\vfil
  \addcontentsline{toc}{part}{\large #1}
 \addtocontents{toc}{\vspace{-3mm}\protect\mbox{}\protect\hrulefill\par}
 {\thispagestyle{empty}
           \psframebox[linearc=0.2,cornersize=absolute,framesep=10pt]{\begin{minipage}[t]{0.9\textwidth}\centering \normalfont\sffamily\bfseries\huge
            \textcolor{bleu}{#1}\end{minipage}}
            \par
            \vskip 50pt          
    }
}
 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% dfinition de l'entte des chapitres
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\def\@makechapterhead#1{%
\vspace*{-20\p@}
  { \raggedright \normalfont\sffamily
    \ifnum \c@secnumdepth >\m@ne
      \if@mainmatter
          \raggedleft\bfseries\chapternumfont\textcolor{bleu}{\thechapter}\par\nobreak
          \vskip-10\p@
          \rule{5cm}{2pt}
        \fi
      \fi
    \begin{flushright}\begin{minipage}[t]{14cm}\raggedleft\huge\bfseries\sffamily #1\end{minipage}\end{flushright}
    \vspace*{50\p@}%
}}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% dfinition de l'entte des chapitres non numrots
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\newcommand{\StarChapter}[2][]{
\chapter*{\vspace*{-60\p@}\raggedleft\bfseries\huge\sffamily #2 \vspace*{50\p@}}
\addcontentsline{toc}{chapter}{#2}
\markboth{\normalfont\normalsize\textit{\textcolor{bleu}{#2}}}{}
\par}

% dfinition de l'entte de la table des matires
\renewcommand{\tableofcontents}{\pagestyle{empty}
\chapter*{\vspace*{-60\p@}\raggedleft\bfseries\huge\sffamily Table des matires \vspace*{50\p@}}
\markboth{\normalfont\normalsize\textit{\textcolor{bleu}{Table des matires}}}{}
\@starttoc{toc}}

% paramtres de la table des matires
\setcounter{tocdepth}{2}
\setcounter{secnumdepth}{2}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%  
% dfinition de la bibliographie
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\renewenvironment{thebibliography}[1]{
\setlength{\parindent}{0cm}
\chapter*{\vspace*{-60\p@}\raggedleft\bfseries\huge\sffamily RFRENCES \vspace*{10\p@}}
\addcontentsline{toc}{part}{RFRENCES}
\addtocontents{toc}{\vspace{-3mm}\protect\mbox{}\protect\hrulefill\par}
%\markboth{\normalfont\normalsize\textit{\textcolor{bleu}{RFRENCES}}}{}
\par
\list{\@biblabel{\@arabic\c@enumiv}}
{\settowidth\labelwidth{\@biblabel{#1}}}
\leftmargin\labelwidth
\advance\leftmargin\labelsep
\@openbib@code
\usecounter{enumiv}
\let\p@enumiv\@empty
\renewcommand\theenumiv{\@arabic\c@enumiv}
\sloppy
\clubpenalty4000
\@clubpenalty \clubpenalty
\widowpenalty4000%
\sfcode`\.\@m
{\def\@noitemerr
{\@latex@warning{Empty `thebibliography' environment}}%
\endlist}
}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%  
% dfinition de l'index
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\renewenvironment{theindex}{
                \columnseprule \z@
                \columnsep 35\p@
                \twocolumn[\@makeschapterhead{\vspace*{-60\p@}\raggedleft\bfseries\huge\sffamily INDEX \vspace*{10\p@}}]%
                \@mkboth{\normalfont\normalsize\textit{\textcolor{bleu}{INDEX}}}%
                        {\normalfont\normalsize\textit{\textcolor{bleu}{INDEX}}}%
                \thispagestyle{plain}\parindent\z@
                \parskip\z@ \@plus .3\p@\relax
                \let\item\@idxitem
                \phantomsection
                \addcontentsline{toc}{chapter}{Index}}
               {\if@restonecol\onecolumn\else\clearpage\fi}
\renewcommand\@idxitem{\par\hangindent 40\p@}
\renewcommand\subitem{\@idxitem \hspace*{20\p@}}
\renewcommand\subsubitem{\@idxitem \hspace*{30\p@}}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% fancyhdr parameters
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\newlength\debordementdroit\setlength\debordementdroit{0pt}
\newlength\debordementgauche\setlength\debordementgauche{30pt}
\pagestyle{fancy}
\fancyheadoffset{\debordementdroit}
\fancyfootoffset{\debordementdroit}
\renewcommand{\chaptermark}[1]{\markboth{\normalfont\normalsize\textit{\textcolor{bleu}{#1}}}{}}
\renewcommand{\sectionmark}[1]{\markright{\normalfont\normalsize\textit{\textcolor{bleu}{\thesection\hspace{2pt} #1}}}{}}
\fancyhf{} \fancyhead[LE,RO]{\normalfont\normalsize\textcolor{bleu}{\thepage}}
\fancyhead[LO]{\itshape{\rightmark}}
\fancyhead[RE]{\itshape{\leftmark}}
\renewcommand{\headrulewidth}{0.5pt}
\addtolength{\headheight}{0.5pt}
\renewcommand{\footrulewidth}{0pt}
\fancypagestyle{plain}{
\fancyhead{}
\renewcommand{\headrulewidth}{0pt}}
\renewcommand{\cleardoublepage}{%
\clearpage\ifodd\c@page\else
\hbox{}
\vspace*{\fill}
\thispagestyle{empty}% <--
\newpage
\fi} 

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% dfinition de l'apparence des sections et sous-sections
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\renewcommand{\@seccntformat}[1]{\llap{\textcolor{bleu}{\csname the#1\endcsname}\hspace{0.5em}}}
                                      
\renewcommand{\section}{\@startsection{section}{1}{\z@}
                       {-4ex \@plus -1ex \@minus -.4ex}%
                       {1ex \@plus.2ex }%
                       {\normalfont\Large\sffamily\bfseries}}
\renewcommand{\subsection}{\@startsection {subsection}{2}{\z@}
                          {-3ex \@plus -0.1ex \@minus -.4ex}%
                          {0.5ex \@plus.2ex }%
                          {\normalfont\fontsize{12}{16}\sffamily\bfseries}}
\renewcommand{\subsubsection}{\@startsection {subsubsection}{3}{\z@}
                          {-2ex \@plus -0.1ex \@minus -.2ex}%
                          {0.2ex \@plus.2ex }%
                          {\normalfont\fontsize{11}{16}\sffamily\bfseries}}
                          
\renewcommand\paragraph{\@startsection{paragraph}{4}{\z@\quad}%
                                    {-2ex \@plus-.2ex \@minus .2ex}%
                                    {0.1ex}%
                                    {\normalfont\fontsize{11}{13}\sffamily\bfseries}}
\renewcommand\subparagraph{\@startsection{subparagraph}{5}{\z@}%
                                       {-2ex \@plus-.1ex \@minus .2ex}%
                                       {0.1ex}%
                                      {\normalfont\normalsize\sffamily\bfseries}}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% dfinition du comportement des guillemets
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\catcode`\=\active \catcode`\=\active
\def{\og\ignorespaces}
\def{\fg}
